import {
  Controller,
  Get,
  Post,
  Body,
  Param,
  Delete,
  Headers,
} from '@nestjs/common'
import { ConnectionsService } from './connections.service'
import { CreateConnectionDto } from './dto/create-connection.dto'

@Controller('connections')
export class ConnectionsController {
  constructor(private readonly connectionsService: ConnectionsService) {}

  // creates a pending request.
  @Post()
  create(
    @Body() createConnectionDto: CreateConnectionDto,
    @Headers('Authorization') authHeader: string,
  ) {
    return this.connectionsService.create(authHeader, createConnectionDto)
  }

  // returns pending connections for the requesting user.
  @Get()
  pending(
    @Headers('Authorization') authHeader: string,
  ) {
    return this.connectionsService.pending(authHeader)
  }

  // accepts a recieved connection. returns unauthorized if the requesting user is
  // not the reciever.
  @Post(':id')
  accept(
    @Headers('Authorization') authHeader: string,
    @Param('id') id: string,
  ) {
    return this.connectionsService.accept(authHeader, +id)
  }

  // declines a recieved connection. returns unauthorized if the requesting user is
  // not the reciever.
  @Post(':id')
  decline(
    @Headers('Authorization') authHeader: string,
    @Param('id') id: string,
  ) {
    return this.connectionsService.decline(authHeader, +id)
  }

  // deletes a sent connection. returns unauthorized if the requesting user is
  // not the sender.
  @Delete(':id')
  remove(
    @Headers('Authorization') authHeader: string,
    @Param('id') id: string,
  ) {
    return this.connectionsService.remove(authHeader, +id)
  }
}
